@@ -10,7 +10,7 @@ BEGIN
 	use Carp;
 	use vars  qw( $VERSION $lcnt_max $ssec );
 
-	$VERSION = "3.0";
+	$VERSION = "3.01";
 }
 
 
@@ -1095,7 +1095,7 @@ __END__
 
 =head1 NAME
 
- Parse::Plain - template parsing engine (version 3.00)
+ Parse::Plain - template parsing engine (version 3.01)
 
 
 =head1 SYNOPSIS
@@ -1144,7 +1144,7 @@ with the same name and any number of different tags in the template.
 
 Block is a construction that begins with line
 
-  B<{{ blockname>
+  {{ blockname
 
 and ends with symbols B<}}>
 
@@ -1220,8 +1220,8 @@ of tagname =E<gt> value pairs or just pass two scalars (tagname and value).
 
 Examples:
 
- B<$t-E<gt>set_tag('mytag', 'value'); # set %%mytag%% to 'value'>
- B<$t-E<gt>set_tag({'mytag' => 'value', 'othertag' => 'otherval');>
+ $t-E<gt>set_tag('mytag', 'value'); # set %%mytag%% to 'value'
+ $t-E<gt>set_tag({'mytag' => 'value', 'othertag' => 'otherval');
 
 Values may be another instances of Parse::Plain. In this case L</parse>
 method will be called on value object. Returned value is a hash
@@ -1466,7 +1466,7 @@ iteration of the block. See L</EXAMPLES> section elsewhere in this document.
 You can also provide a referense to hash of tags used for parsing
 current block. For example:
 
-  B<$t-E<gt>parse('blockname', {'tag1' =E<gt> 'val1', 'tag2' =E<gt> 'val2'});>
+  $t-E<gt>parse('blockname', {'tag1' =E<gt> 'val1', 'tag2' =E<gt> 'val2'});
 
 If you don't specify this hash reference hash filled by
 L</set_tag> functions wiil be used instead. You can also use both
@@ -1528,7 +1528,7 @@ o
 
 One will be parsed to
 
-B<      Hello>
+      Hello
 
 line. However since version 3.00 you could also use such template:
 
